import datetime

from django.core.management.base import BaseCommand
from emissions.models import Absence

from nonstop.models import (
    RecurringRandomDirectoryDiffusion,
    RecurringRandomDirectoryOccurence,
    RecurringStreamDiffusion,
    RecurringStreamOccurence,
)


class Command(BaseCommand):
    def handle(self, verbosity, **kwargs):
        for diffusion in RecurringStreamDiffusion.objects.filter(is_active=True):
            next_planned_date = diffusion.schedule.get_next_planned_date(since=datetime.datetime.now())
            try:
                occurence = RecurringStreamOccurence.objects.get(
                    diffusion=diffusion, datetime=next_planned_date
                )
            except RecurringStreamOccurence.DoesNotExist:
                occurence = RecurringStreamOccurence(diffusion=diffusion, datetime=next_planned_date)
            if (
                occurence.id
                and Absence.objects.filter(
                    emission=diffusion.schedule.emission, datetime=next_planned_date
                ).exists()
            ):
                occurence.delete()
            elif not occurence.id:
                occurence.save()

        for diffusion in RecurringRandomDirectoryDiffusion.objects.filter(is_active=True):
            next_planned_date = diffusion.schedule.get_next_planned_date(since=datetime.datetime.now())
            try:
                occurence = RecurringRandomDirectoryOccurence.objects.get(
                    diffusion=diffusion, datetime=next_planned_date
                )
            except RecurringRandomDirectoryOccurence.DoesNotExist:
                occurence = RecurringRandomDirectoryOccurence(diffusion=diffusion, datetime=next_planned_date)
            if not occurence.id:
                occurence.save()
