from django.conf.urls import url
from django.urls import reverse_lazy
from django.views.generic import RedirectView

from .views import (
    AddSomaDiffusionView,
    AjaxProgram,
    ArtistDetailView,
    ArtistListView,
    ArtistTracksMetadataView,
    CleanupView,
    DelSomaDiffusionView,
    DiffusionPropertiesView,
    JingleAddView,
    JingleSettingsView,
    JinglesListView,
    MuninTracks,
    QuickLinksView,
    RandomTracksMetadataView,
    RecentTracksMetadataView,
    RedirectTodayView,
    SearchCsvView,
    SearchView,
    SomaDayArchiveCsvView,
    SomaDayArchiveView,
    StatisticsView,
    TrackDetailView,
    UploadTracksView,
    ZoneSettings,
    ZonesView,
    ZoneTracklistPercents,
    force_switch_view,
    jingle_audio_view,
    track_sound,
)

urlpatterns = [
    url(r'^$', QuickLinksView.as_view(), name='nonstop-quick-links'),
    url(r'^today/$', RedirectTodayView.as_view(), name='nonstop-today'),
    url(r'^stats/$', StatisticsView.as_view(), name='nonstop-stats'),
    url(r'^tracks/(?P<pk>\d+)/$', TrackDetailView.as_view(), name='track-view'),
    url(r'^tracks/(?P<pk>\d+)/sound/$', track_sound, name='nonstop-track-sound'),
    url(r'^artists/$', ArtistListView.as_view(), name='artist-list'),
    url(r'^artists/(?P<pk>\d+)/$', ArtistDetailView.as_view(), name='artist-view'),
    url(r'^jingles/$', JinglesListView.as_view(), name='nonstop-jingles-list'),
    url(r'^jingles/add/$', JingleAddView.as_view(), name='nonstop-jingle-add'),
    url(r'^jingles/(?P<pk>\d+)/$', JingleSettingsView.as_view(), name='nonstop-jingle-settings'),
    url(r'^zones/$$', ZonesView.as_view(), name='nonstop-zones'),
    url(r'^zones/(?P<slug>[\w-]+)/settings/$', ZoneSettings.as_view(), name='zone-settings'),
    # Example: /2012/nov/10/
    url(
        r'^(?P<year>[0-9]{4})/(?P<month>[-\w]+)/(?P<day>[0-9]+)/$',
        SomaDayArchiveView.as_view(),
        name="archive_day",
    ),
    url(
        r'^(?P<year>[0-9]{4})/(?P<month>[-\w]+)/(?P<day>[0-9]+)/csv$',
        SomaDayArchiveCsvView.as_view(),
        name="archive_day_csv",
    ),
    url(r'^upload/$', UploadTracksView.as_view(), name='nonstop-upload-tracks'),
    url(r'^metadata/recent/$', RecentTracksMetadataView.as_view(), name='nonstop-recent-tracks'),
    url(r'^metadata/random/$', RandomTracksMetadataView.as_view(), name='nonstop-random-tracks'),
    url(
        r'^metadata/artist/(?P<artist_pk>\d+)/$',
        ArtistTracksMetadataView.as_view(),
        name='nonstop-artist-metadata-tracks',
    ),
    url(r'^search/$', SearchView.as_view(), name='nonstop-search'),
    url(r'^search/csv$', SearchCsvView.as_view(), name='nonstop-search-csv'),
    url(r'^quick-links/$', RedirectView.as_view(url=reverse_lazy('nonstop-quick-links'))),
    url(r'^cleanup/$', CleanupView.as_view(), name='nonstop-cleanup'),
    url(r'^force-switch/$', force_switch_view, name='nonstop-force-switch'),
    # soma management for episodes
    url(r'^diffusion/(?P<pk>\d+)/add/$', AddSomaDiffusionView.as_view(), name='nonstop-add-diffusion'),
    url(
        r'^diffusion/(?P<pk>\d+)/properties/$',
        DiffusionPropertiesView.as_view(),
        name='nonstop-diffusion-properties',
    ),
    url(r'^diffusion/(?P<pk>\d+)/del/$', DelSomaDiffusionView.as_view(), name='nonstop-del-diffusion'),
    url(r'^api/jingle/(?P<pk>\d+)/$', jingle_audio_view),
    # ajax parts
    url(
        r'^ajax/zones/(?P<slug>[\w-]+)/percents/$',
        ZoneTracklistPercents.as_view(),
        name='nonstop-ajax-zone-percents',
    ),
]

public_urlpatterns = [
    url(r'^api/munin/tracks/(?P<config>config/)?$', MuninTracks.as_view()),
    url(r'^ajax/program/(?P<date>[\d-]*)$', AjaxProgram.as_view(), name='nonstop-ajax-program'),
]
